# Generated by Django 4.2.16 on 2025-02-26 14:08

from django.db import migrations, models
import django.db.models.deletion


def clear_outcome(apps, _):
    Action = apps.get_model('halo', 'Action')
    Action.objects.update(outcome=None)

class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0023_action_non_billable_time_action_outcome_and_more'),
    ]

    operations = [
        migrations.RunPython(clear_outcome, reverse_code=migrations.RunPython.noop),
        migrations.CreateModel(
            name='Outcome',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('outcome', models.CharField(max_length=255)),
                ('button_name', models.CharField(max_length=255)),
                ('label_long', models.CharField(max_length=255)),
                ('sequence', models.IntegerField()),
                ('hidden', models.BooleanField(default=False)),
                ('icon', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='OutcomeTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_outcome',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.outcome',),
        ),
        migrations.AlterField(
            model_name='action',
            name='outcome',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.outcome'),
        ),
    ]
