# Generated by Django 4.2.11 on 2024-12-13 15:33

from django.db import migrations, models
import django.db.models.deletion


def nullify_team_field(apps, schema_editor):
    Ticket = apps.get_model('halo', 'Ticket')
    Ticket.objects.update(team=None)


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0018_agent_teams'),
    ]

    operations = [
        migrations.RunPython(nullify_team_field, reverse_code=nullify_team_field),
        migrations.AlterField(
            model_name='ticket',
            name='team',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.team'),
        ),
    ]