# Generated by Django 4.2.11 on 2024-09-24 09:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0011_tickettype_remove_project_agent_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='main_site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='client_primary', to='halo.site'),
        ),
    ]
