# Generated by Django 4.2.11 on 2024-10-21 12:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0015_alter_ticket_details_alter_ticket_email_to_list_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='appointment',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='halo.site'),
        ),
        migrations.AlterField(
            model_name='client',
            name='main_site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='client_primary', to='halo.site'),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='halo.site'),
        ),
        migrations.AlterField(
            model_name='site',
            name='sla',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='halo.sla'),
        ),
    ]
