# Generated by Django 4.2.11 on 2025-02-10 14:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0022_alter_budgetdata_ticket'),
    ]

    operations = [
        migrations.AddField(
            model_name='action',
            name='non_billable_time',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='action',
            name='outcome',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='action',
            name='travel_time',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
