# Generated by Django 4.2.16 on 2025-02-26 16:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0024_outcome_outcometracker_alter_action_outcome'),
    ]

    operations = [
        migrations.CreateModel(
            name='ChargeRate',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='ChargeRateTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_chargerate',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.chargerate',),
        ),
    ]
