# Generated by Django 4.2.11 on 2024-09-13 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0007_alter_sla_track_sla_fix_by_time_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='site',
            name='delivery_address',
            field=models.CharField(max_length=1000),
        ),
    ]
