# Generated by Django 4.2.11 on 2024-12-13 10:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0017_team_teamtracker'),
    ]

    operations = [
        migrations.AddField(
            model_name='agent',
            name='teams',
            field=models.ManyToManyField(blank=True, related_name='agents', to='halo.team'),
        ),
    ]
