# Generated by Django 4.2.11 on 2024-08-15 10:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='agent',
            old_name='isdisabled',
            new_name='is_disabled',
        ),
        migrations.RenameField(
            model_name='priority',
            old_name='ishidden',
            new_name='is_hidden',
        ),
        migrations.RenameField(
            model_name='ticket',
            old_name='lastactiondate',
            new_name='last_action_date',
        ),
        migrations.RenameField(
            model_name='ticket',
            old_name='targetdate',
            new_name='target_date',
        ),
        migrations.RenameField(
            model_name='ticket',
            old_name='targettime',
            new_name='target_time',
        ),
    ]
