# Generated by Django 4.2.11 on 2024-09-13 13:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0005_sla_site_halouser_ticket_sla'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='sla',
            name='hours_are_local_time',
        ),
    ]
