# Generated by Django 4.2.17 on 2025-03-14 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0024_ticket_date_closed'),
        ('halo', '0025_chargerate_chargeratetracker'),
    ]

    operations = [
    ]
