# Generated by Django 4.2.11 on 2024-09-13 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0006_remove_sla_hours_are_local_time'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sla',
            name='track_sla_fix_by_time',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='sla',
            name='track_sla_response_time',
            field=models.BooleanField(default=False),
        ),
    ]
