# Generated by Django 4.2.11 on 2024-08-16 11:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0003_alter_ticket_agent_alter_ticket_client_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='agent',
            options={'verbose_name_plural': 'Agents'},
        ),
        migrations.AlterModelOptions(
            name='client',
            options={'verbose_name_plural': 'Clients'},
        ),
        migrations.AlterModelOptions(
            name='priority',
            options={'verbose_name_plural': 'Priorities'},
        ),
        migrations.AlterModelOptions(
            name='status',
            options={'verbose_name_plural': 'Statuses'},
        ),
        migrations.AlterModelOptions(
            name='ticket',
            options={'verbose_name_plural': 'Tickets'},
        ),
    ]
