# Generated by Django 4.2.11 on 2024-10-21 12:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0014_alter_action_project_alter_action_ticket'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='details',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='email_to_list',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='service_status_note',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='ticket_tags',
            field=models.TextField(blank=True, null=True),
        ),
    ]
