# Generated by Django 4.2.11 on 2024-09-19 15:00

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0008_alter_site_delivery_address'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='halouser',
            options={'verbose_name_plural': 'Halo Users'},
        ),
        migrations.AlterModelOptions(
            name='site',
            options={'verbose_name_plural': 'Sites'},
        ),
        migrations.AlterModelOptions(
            name='sla',
            options={'verbose_name_plural': 'SLAs'},
        ),
        migrations.AddField(
            model_name='ticket',
            name='category_1',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='category_2',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='category_3',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='category_4',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='cost',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='date_assigned',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='date_occurred',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='deadline_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='email_to_list',
            field=models.TextField(blank=True, max_length=2000, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='end_user_status',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='estimate',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='estimated_days',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='exclude_from_sla',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='fix_by_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='flagged',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='impact',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='inactive',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='last_incoming_email',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='on_hold',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='project_money_actual',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='project_time_actual',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='read',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='reported_by',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='respond_by_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='response_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='reviewed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='service_status_note',
            field=models.TextField(blank=True, max_length=2000, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.site'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='sla_hold_time',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='sla_response_state',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='start_date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='start_time',
            field=models.TimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='team',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='ticket_tags',
            field=models.TextField(blank=True, max_length=2000, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='urgency',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='use',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.halouser'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='user_email',
            field=models.EmailField(blank=True, max_length=254, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='first_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='initials',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='login',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='surname',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='halouser',
            name='use',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='site',
            name='delivery_address',
            field=models.CharField(blank=True, max_length=1000, null=True),
        ),
        migrations.AlterField(
            model_name='site',
            name='use',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('summary', models.CharField(blank=True, max_length=1000, null=True)),
                ('details', models.TextField(blank=True, max_length=8000, null=True)),
                ('appointment_type', models.CharField(blank=True, max_length=255, null=True)),
                ('closed_in_integration_system', models.BooleanField(default=False)),
                ('cost', models.FloatField(blank=True, null=True)),
                ('date_assigned', models.DateTimeField(blank=True, null=True)),
                ('date_occurred', models.DateTimeField(blank=True, null=True)),
                ('deadline_date', models.DateTimeField(blank=True, null=True)),
                ('estimate', models.FloatField(blank=True, null=True)),
                ('estimate_days', models.FloatField(blank=True, null=True)),
                ('exclude_from_sla', models.BooleanField(default=False)),
                ('fix_by_date', models.DateTimeField(blank=True, null=True)),
                ('flagged', models.BooleanField(default=False)),
                ('impact', models.IntegerField(blank=True, null=True)),
                ('impact_level', models.IntegerField(blank=True, null=True)),
                ('inactive', models.BooleanField(default=False)),
                ('last_action_date', models.DateTimeField(blank=True, null=True)),
                ('last_incoming_email', models.DateTimeField(blank=True, null=True)),
                ('on_hold', models.BooleanField(default=False)),
                ('project_time_actual', models.FloatField(blank=True, null=True)),
                ('respond_by_date', models.DateTimeField(blank=True, null=True)),
                ('reviewed', models.BooleanField(default=False)),
                ('source', models.IntegerField(blank=True, null=True)),
                ('start_date', models.DateField(blank=True, null=True)),
                ('start_time', models.TimeField(blank=True, null=True)),
                ('target_date', models.DateField(blank=True, null=True)),
                ('target_time', models.TimeField(blank=True, null=True)),
                ('team', models.CharField(blank=True, max_length=255, null=True)),
                ('urgency', models.IntegerField(blank=True, null=True)),
                ('use', models.CharField(blank=True, max_length=255, null=True)),
                ('agent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.agent')),
                ('client', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.client')),
                ('priority', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.priority')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.site')),
                ('status', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.status')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.halouser')),
            ],
            options={
                'verbose_name_plural': 'Appointments',
            },
        ),
        migrations.CreateModel(
            name='Appointment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(blank=True, max_length=1000, null=True)),
                ('start_date', models.DateTimeField(blank=True, null=True)),
                ('end_date', models.DateTimeField(blank=True, null=True)),
                ('appointment_type', models.CharField(blank=True, max_length=255, null=True)),
                ('is_private', models.BooleanField(default=False)),
                ('is_task', models.BooleanField(default=False)),
                ('complete_status', models.IntegerField(blank=True, null=True)),
                ('colour', models.CharField(blank=True, max_length=50, null=True)),
                ('online_meeting_url', models.CharField(blank=True, max_length=2000, null=True)),
                ('agent', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.agent')),
                ('client', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.client')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.site')),
                ('ticket', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.ticket')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.halouser')),
            ],
            options={
                'verbose_name_plural': 'Appointments',
            },
        ),
        migrations.AddField(
            model_name='ticket',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.project'),
        ),
    ]
