# Generated by Django 4.2.16 on 2025-06-18 10:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0028_merge_20250321_1529'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='appointment_type',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
