# Generated by Django 4.2.16 on 2025-01-23 15:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0021_alter_budgetdata_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='budgetdata',
            name='ticket',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='halo.ticket'),
        ),
    ]
