# Generated by Django 4.2.11 on 2025-01-17 14:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0020_budgettype_ticket_itil_request_type_budgetdata_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='budgetdata',
            options={'verbose_name_plural': 'Budget Data'},
        ),
    ]
