# Generated by Django 4.2.17 on 2025-03-21 15:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0027_alter_action_charge_rate_alter_ticket_deadline_date_and_more'),
        ('halo', '0027_alter_ticket_appointment_type_and_more'),
    ]

    operations = [
    ]
