# Generated by Django 4.2.11 on 2024-09-24 09:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0010_agenttracker_appointmenttracker_clienttracker_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='TicketType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('agents_can_select', models.BooleanField(default=False)),
                ('end_users_can_select', models.BooleanField(default=False)),
                ('allow_attachments', models.BooleanField(default=False)),
                ('can_create', models.BooleanField(default=False)),
                ('copy_attachments_to_child', models.BooleanField(default=False)),
                ('copy_attachments_to_related', models.BooleanField(default=False)),
                ('use', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.RemoveField(
            model_name='project',
            name='agent',
        ),
        migrations.RemoveField(
            model_name='project',
            name='client',
        ),
        migrations.RemoveField(
            model_name='project',
            name='priority',
        ),
        migrations.RemoveField(
            model_name='project',
            name='site',
        ),
        migrations.RemoveField(
            model_name='project',
            name='status',
        ),
        migrations.RemoveField(
            model_name='project',
            name='user',
        ),
        migrations.DeleteModel(
            name='ProjectTracker',
        ),
        migrations.AddField(
            model_name='client',
            name='colour',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='client',
            name='main_site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.site'),
        ),
        migrations.AddField(
            model_name='client',
            name='phone_number',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='appointment_type',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='impact_level',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.ticket'),
        ),
        migrations.DeleteModel(
            name='Project',
        ),
        migrations.CreateModel(
            name='TicketTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_tickettype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.tickettype',),
        ),
        migrations.AddField(
            model_name='ticket',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='halo.tickettype'),
        ),
    ]
