# Generated by Django 4.2.16 on 2025-03-20 12:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0026_merge_20250314_1651'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='appointment_type',
            field=models.IntegerField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='last_action_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
