# Generated by Django 4.2.11 on 2024-08-13 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SyncJob',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_time', models.DateTimeField()),
                ('end_time', models.DateTimeField(blank=True, null=True)),
                ('entity_name', models.CharField(max_length=100)),
                ('synchronizer_class', models.CharField(blank=True, max_length=100, null=True)),
                ('added', models.PositiveIntegerField(null=True)),
                ('updated', models.PositiveIntegerField(null=True)),
                ('deleted', models.PositiveIntegerField(null=True)),
                ('skipped', models.PositiveIntegerField(null=True)),
                ('success', models.BooleanField(null=True)),
                ('message', models.TextField(blank=True, null=True)),
                ('sync_type', models.CharField(default='full', max_length=32)),
            ],
        ),
    ]
