# Generated by Django 4.2.16 on 2025-02-28 15:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0023_action_non_billable_time_action_outcome_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='date_closed',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
