# Generated by Django 4.2.11 on 2024-09-20 07:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('halo', '0009_alter_halouser_options_alter_site_options_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='AgentTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_agent',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.agent',),
        ),
        migrations.CreateModel(
            name='AppointmentTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_appointment',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.appointment',),
        ),
        migrations.CreateModel(
            name='ClientTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_client',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.client',),
        ),
        migrations.CreateModel(
            name='HaloUserTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_halouser',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.halouser',),
        ),
        migrations.CreateModel(
            name='PriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_priority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.priority',),
        ),
        migrations.CreateModel(
            name='ProjectTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_project',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.project',),
        ),
        migrations.CreateModel(
            name='SiteTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_site',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.site',),
        ),
        migrations.CreateModel(
            name='SLATracker',
            fields=[
            ],
            options={
                'db_table': 'halo_sla',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.sla',),
        ),
        migrations.CreateModel(
            name='StatusTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_status',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.status',),
        ),
        migrations.CreateModel(
            name='TicketTracker',
            fields=[
            ],
            options={
                'db_table': 'halo_ticket',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('halo.ticket',),
        ),
        migrations.RenameField(
            model_name='ticket',
            old_name='parent',
            new_name='project',
        ),
    ]
